@@ -31,6 +31,7 @@ pub trait Soundex: Deref<Target = str> {
     fn soundex(&self) -> String;
 }
 
+/// Default implementation for strings.
 impl<T: Deref<Target = str>> Soundex for T {
     fn soundex(&self) -> String {
         if self.is_empty() {
@@ -62,8 +63,11 @@ impl<T: Deref<Target = str>> Soundex for T {
 
             count += 1;
 
-            if !cfg!(feature = "full") && count == 4 {
-                break;
+            #[cfg(not(feature = "full"))]
+            {
+                if count == 4 {
+                    break;
+                }
             }
         }
 
@@ -112,7 +116,6 @@ where
 
 #[cfg(test)]
 mod tests {
-
     use super::Soundex;
     use crate::equal;
 
